package com.cweb.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.cweb.config.SysConst;
import com.hai.common.Base64Util;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.pay.util.XmlUtil;
import com.hai.common.pay.util.sdk.WXPayConstants;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.*;
import com.hai.config.*;
import com.hai.dao.HighGasOrderPushMapper;
import com.hai.entity.*;
import com.hai.enum_type.MerchantStoreSourceType;
import com.hai.model.*;
import com.hai.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.apache.http.HttpEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.ssl.SSLContexts;
import org.apache.http.util.EntityUtils;
import org.bouncycastle.util.encoders.UrlBase64;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.util.IdGenerator;
import org.springframework.web.bind.annotation.*;
import sun.nio.cs.StreamEncoder;

import javax.annotation.Resource;
import javax.net.ssl.SSLContext;
import javax.servlet.http.HttpServletRequest;
import java.io.*;
import java.math.BigDecimal;
import java.nio.charset.StandardCharsets;
import java.security.KeyStore;
import java.util.*;

/**
 * @Auther: 胡锐
 * @Description:
 * @Date: 2021/3/26 23:08
 */
@Controller
@RequestMapping(value = "/test")
@Api(value = "订单接口")
public class HighTestController {

    private static Logger log = LoggerFactory.getLogger(HighTestController.class);

    @Resource
    private HighMerchantService highMerchantService;

    @Resource
    private HighMerchantStoreService highMerchantStoreService;

    @Resource
    private HighGasOilPriceService highGasOilPriceService;

    @Resource
    private HighOrderService highOrderService;

    @Autowired
    private UserCenter userCenter;

    @Resource
    private HighProfitSharingRecordService highProfitSharingRecordService;


    @Resource
    private BaiduVoiceService baiduVoiceService;

    @Resource
    private ShellGroupService shellGroupService;

    @Resource
    private HighGasService gasService;

    @Resource
    private BsMsgService bsMsgService;


    @RequestMapping(value = "/queryGasInfoByGasId", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "根据油站 id 拉取最新的油站数据")
    public ResponseData queryGasInfoByGasId(@RequestParam(name = "gasId", required = true) String gasId, HttpServletRequest request) {
        try {
            return ResponseMsgUtil.success(TuanYouConfig.queryGasInfoByGasId(gasId));

        } catch (Exception e) {
            log.error("HighUserCardController --> getHuiLianTongCardInfo() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/initTYMerchantStore", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "初始化加油站")
    public ResponseData initTYMerchantStore(@RequestParam(name = "merchantId", required = true) Long merchantId) throws Exception {

        HighMerchantModel merchant = highMerchantService.getMerchantById(merchantId);
        if (merchant == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未找到商户");
        }
        JSONObject jsonObjectP = TuanYouConfig.queryGasInfoListByPage(1, 1000);
        JSONObject resultObjectP = jsonObjectP.getObject("result", JSONObject.class);

        for (int i = 1; i <= resultObjectP.getInteger("totalPageNum").intValue(); i++) {
            JSONObject jsonObject = TuanYouConfig.queryGasInfoListByPage(i, 1000);
            JSONObject resultObject = jsonObject.getObject("result", JSONObject.class);
            JSONArray jsonArray = resultObject.getJSONArray("gasInfoList");
            HighMerchantStore highMerchantStore;
            HighGasOilPrice highGasOilPrice;
            for (Object gasObject : jsonArray) {
                JSONObject object = JSONObject.parseObject(JSONObject.toJSONString(gasObject));
                HighMerchantStoreModel store = highMerchantStoreService.getMerchantStoreByKey(object.getString("gasId"));
                if (store != null) {
                    store.setType(1);
                    store.setMerchantId(merchant.getId());
                    store.setCompanyId(merchant.getCompanyId());
                    store.setStoreKey(object.getString("gasId"));
                    store.setStoreName(object.getString("gasName"));
                    store.setStoreLogo(object.getString("gasLogoSmall"));
                    store.setRegionId(object.getLong("provinceCode"));
                    store.setRegionName(object.getString("provinceName"));
                    store.setAddress(object.getString("gasAddress"));
                    store.setLongitude(object.getString("gasAddressLongitude"));
                    store.setLatitude(object.getString("gasAddressLatitude"));
                    store.setStatus(object.getInteger("gasStatus"));
                    store.setOperatorId(0L);
                    store.setOperatorName("系统创建");
                    store.setUpdateTime(new Date());
                    store.setExt1(object.getString("gasSourceId"));
                    highMerchantStoreService.updateMerchantStoreDetail(store);

                    JSONArray oilPriceList = object.getJSONArray("oilPriceList");
                    for (Object oilPrice : oilPriceList) {
                        JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));
                        // 查询门店油号
                        highGasOilPrice = highGasOilPriceService.getGasOilPriceByStoreAndOilNo(store.getId(), oilPriceObject.getString("oilNo"));
                        if (highGasOilPrice == null) {
                            highGasOilPrice = new HighGasOilPrice();
                            highGasOilPrice.setMerchantStoreId(store.getId());
                            highGasOilPrice.setOilNo(oilPriceObject.getString("oilNo"));
                            highGasOilPrice.setOilNoName(oilPriceObject.getString("oilNoName"));
                            highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("priceVip"));
                            highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("priceGun"));
                            highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("priceOfficial"));
                            highGasOilPrice.setOilType(oilPriceObject.getInteger("oilType"));
                            highGasOilPrice.setOilTypeName(oilPriceObject.getString("oilTypeName"));
                        } else {
                            highGasOilPrice.setMerchantStoreId(store.getId());
                            highGasOilPrice.setOilNo(oilPriceObject.getString("oilNo"));
                            highGasOilPrice.setOilNoName(oilPriceObject.getString("oilNoName"));
                            highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("priceVip"));
                            highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("priceGun"));
                            highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("priceOfficial"));
                            highGasOilPrice.setOilType(oilPriceObject.getInteger("oilType"));
                            highGasOilPrice.setOilTypeName(oilPriceObject.getString("oilTypeName"));
                        }
                        highGasOilPriceService.editGasOilPrice(highGasOilPrice);
                    }
                } else {
                    highMerchantStore = new HighMerchantStore();
                    highMerchantStore.setType(1);
                    highMerchantStore.setMerchantId(merchant.getId());
                    highMerchantStore.setCompanyId(merchant.getCompanyId());
                    highMerchantStore.setStoreKey(object.getString("gasId"));
                    highMerchantStore.setStoreName(object.getString("gasName"));
                    highMerchantStore.setStoreLogo(object.getString("gasLogoSmall"));
                    highMerchantStore.setRegionId(object.getLong("provinceCode"));
                    highMerchantStore.setRegionName(object.getString("provinceName"));
                    highMerchantStore.setAddress(object.getString("gasAddress"));
                    highMerchantStore.setLongitude(object.getString("gasAddressLongitude"));
                    highMerchantStore.setLatitude(object.getString("gasAddressLatitude"));
                    highMerchantStore.setStatus(1);
                    highMerchantStore.setOperatorId(0L);
                    highMerchantStore.setOperatorName("系统创建");
                    highMerchantStore.setCreateTime(new Date());
                    highMerchantStore.setUpdateTime(new Date());
                    highMerchantStore.setExt1(object.getString("gasSourceId"));
                    HighMerchantStoreModel merchantStoreModel = new HighMerchantStoreModel();
                    BeanUtils.copyProperties(highMerchantStore, merchantStoreModel);
                    highMerchantStoreService.insertMerchantStore(merchantStoreModel);

                    JSONArray oilPriceList = object.getJSONArray("oilPriceList");
                    for (Object oilPrice : oilPriceList) {
                        JSONObject oilPriceObject = JSONObject.parseObject(JSONObject.toJSONString(oilPrice));
                        highGasOilPrice = new HighGasOilPrice();
                        highGasOilPrice.setMerchantStoreId(merchantStoreModel.getId());
                        highGasOilPrice.setOilNo(oilPriceObject.getString("oilNo"));
                        highGasOilPrice.setOilNoName(oilPriceObject.getString("oilNoName"));
                        highGasOilPrice.setPriceVip(oilPriceObject.getBigDecimal("priceVip"));
                        highGasOilPrice.setPriceGun(oilPriceObject.getBigDecimal("priceGun"));
                        highGasOilPrice.setPriceOfficial(oilPriceObject.getBigDecimal("priceOfficial"));
                        highGasOilPrice.setOilType(oilPriceObject.getInteger("oilType"));
                        highGasOilPrice.setOilTypeName(oilPriceObject.getString("oilTypeName"));
                        highGasOilPriceService.editGasOilPrice(highGasOilPrice);
                    }
                }
            }
        }
        return ResponseMsgUtil.success("初始化完成");
    }

    @RequestMapping(value = "/detectTYMerchantStore", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "检测加油站")
    public ResponseData detectTYMerchantStore(@RequestParam(name = "merchantId", required = true) Long merchantId) throws Exception {

        HighMerchantModel merchant = highMerchantService.getMerchantById(merchantId);
        if (merchant == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "未找到商户");
        }

        Map<String, Object> param = new HashMap<>();
        param.put("merchantId", merchant.getId());
        List<HighMerchantStore> stores = highMerchantStoreService.getMerchantStoreList(param);

        for (HighMerchantStore store : stores) {
            JSONObject jsonObject = TuanYouConfig.queryGasInfoByGasId(store.getStoreKey());
            if (jsonObject != null && jsonObject.getString("code").equals("200")) {
                JSONObject result = jsonObject.getJSONObject("result");
                store.setStatus(result.getInteger("gasStatus"));
            } else {
                store.setStatus(0);
            }
            highMerchantStoreService.updateMerchantStoreDetail(store);
        }
        return ResponseMsgUtil.success("初始化完成");
    }


    @RequestMapping(value = "/queryCompanyAccountInfo2JD", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询团油余额")
    public ResponseData queryCompanyAccountInfo2JD() {
        try {

            return ResponseMsgUtil.success(TuanYouConfig.queryCompanyAccountInfo2JD());
        } catch (Exception e) {
            log.error("HighOrderController --> queryCompanyAccountInfo2JD() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/queryCompanyPriceDetail", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询团油余额")
    public ResponseData queryCompanyPriceDetail() {
        try {

            return ResponseMsgUtil.success(TuanYouConfig.queryCompanyPriceDetail("LW000115995", "92"));
        } catch (Exception e) {
            log.error("HighOrderController --> queryCompanyAccountInfo2JD() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/starbucksOrdersPay", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "星巴克支付")
    public ResponseData starbucksOrdersPay(@RequestParam(name = "orderNo", required = true) String orderNo) {
        try {
            return ResponseMsgUtil.success(QianZhuConfig.starbucksOrdersPay(orderNo));
        } catch (Exception e) {
            log.error("HighOrderController --> getBackendToken() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/payKfcOrder", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "肯德基支付")
    public ResponseData payKfcOrder(@RequestParam(name = "orderNo", required = true) String orderNo) {
        try {
            return ResponseMsgUtil.success(QianZhuConfig.payKfcOrder(orderNo));
        } catch (Exception e) {
            log.error("HighOrderController --> getBackendToken() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/wxSplitAccount", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "微信分账")
    public ResponseData wxSplitAccount() {
        try {
            HighOrder orderNo = highOrderService.getOrderByOrderNo("HF2021101812025050304");
            wxProfitsharing(orderNo.getOrderNo(), orderNo.getPaySerialNo(), orderNo.getPayRealPrice());
            return ResponseMsgUtil.success("分账成功");
        } catch (Exception e) {
            log.error("HighOrderController --> getOrderById() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/queryStaging", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "分期查询")
    public ResponseData queryStaging(@RequestParam(name = "oriOrgTrace", required = true) String oriOrgTrace, HttpServletRequest request) {
        try {
            String orgTrace = CommonSysConst.getSysConfig().getUnionStagingPayOrgId().substring(0, 4)
                    + CommonSysConst.getSysConfig().getUnionStagingPayOrgId().substring(CommonSysConst.getSysConfig().getUnionStagingPayOrgId().length() - 4, CommonSysConst.getSysConfig().getUnionStagingPayOrgId().length())
                    + DateUtil.format(new Date(), DateUtil.YMDHMS)
                    + IDGenerator.nextId(6);
            return ResponseMsgUtil.success(UnionStagingPayConfig.queryStaging(orgTrace, oriOrgTrace, "", new Date(), request));

        } catch (Exception e) {
            log.error("HighOrderController --> unionStagingPay() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }
/*
    @RequestMapping(value = "/orderToRefund", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "退款")
    public ResponseData orderToRefund(HttpServletRequest request) {
        try {
            OrderRefundModel orderRefundModel = WxOrderConfig.orderToRefund("4200001301202202035413938093", new BigDecimal("30.80"), new BigDecimal("16.90"));

            return ResponseMsgUtil.success(orderRefundModel);

        } catch (Exception e) {
            log.error("HighOrderController --> orderToRefund() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }*/

    @RequestMapping(value = "/sendCNPCTicket", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "订单查询")
    public ResponseData sendCNPCTicket(@RequestParam(name = "couponKey", required = true) String couponKey, HttpServletRequest request) {
        try {
            String orderNo = System.currentTimeMillis()+"";
            // 预发码
            JSONObject preSendCoupon = ChongQingCNPCService.preSendCoupon(couponKey, orderNo, 1, "17726395120");
            if (preSendCoupon.getInteger("status").equals(1)) {
                // 给用户发码
                JSONObject response = ChongQingCNPCService.sendCNPCTicket(couponKey, orderNo, 1, "17726395120");
                return ResponseMsgUtil.success(response);

            }
            return ResponseMsgUtil.success(null);
        } catch (Exception e) {
            log.error("HighOrderController --> unionStagingPay() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/queryCoupon", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "订单查询")
    public ResponseData queryCoupon(@RequestParam(name = "couponNo", required = true) String couponNo, HttpServletRequest request) {
        try {

            return ResponseMsgUtil.success(ChongQingCNPCService.queryCoupon(couponNo));

        } catch (Exception e) {
            log.error("HighOrderController --> unionStagingPay() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    public void wxProfitsharing(String transaction_id, String out_order_no, BigDecimal amount) {
        try {
            Map<String, String> param = new LinkedHashMap<>();
            param.put("appid", "wx637bd6f7314daa46");
            param.put("mch_id", "1289663601");
            param.put("sub_mch_id", "1609882817"); // 个体户黎杨珍
            param.put("transaction_id", transaction_id);
            param.put("out_order_no", out_order_no);
            param.put("nonce_str", WxUtils.makeNonStr());

            // 分账金额
            BigDecimal porofitSharingAmount = amount;

            List<Map<String, Object>> receiversList = new ArrayList<>();
            Map<String, Object> receiversMap = new LinkedHashMap<>();
            receiversMap.put("type", "MERCHANT_ID");
            receiversMap.put("account", "1603942866");
            receiversMap.put("amount", porofitSharingAmount.multiply(new BigDecimal("100")).intValue());
            receiversMap.put("description", "分给商户【惠昕石化】");
            receiversList.add(receiversMap);
            param.put("receivers", JSONObject.toJSONString(receiversList));
            String signStr = WxUtils.generateSignature(param, "Skufk5oi85wDFGl888i6wsRSTkdd5df5", WXPayConstants.SignType.HMACSHA256);
            param.put("sign", signStr);
            String resultXmL = this.doRefundRequest(param.get("mch_id"), null, WxUtils.mapToXml(param));

            // 请求分账返回的结果
            ResultProfitSharing resultProfitSharing = XmlUtil.getObjectFromXML(resultXmL, ResultProfitSharing.class);

            if (!resultProfitSharing.getResult_code().equals("FAIL")) {
                HighProfitSharingRecord sharingRecord = new HighProfitSharingRecord();
                sharingRecord.setOutOrderNo(resultProfitSharing.getOut_order_no());
                sharingRecord.setTransactionId(resultProfitSharing.getTransaction_id());
                sharingRecord.setOrderId(resultProfitSharing.getOrder_id());
                sharingRecord.setStatus(resultProfitSharing.getResult_code());
                sharingRecord.setPrice(amount);
                sharingRecord.setCreateTime(new Date());
                sharingRecord.setContent(resultXmL);
                highProfitSharingRecordService.insert(sharingRecord);
            }

        } catch (Exception e) {
            log.error("CmsContentController --> getCorporateAdvertising() error!", e);
        }
    }

    public CloseableHttpClient readCertificate(String mchId) throws Exception {
        /**
         * 注意PKCS12证书 是从微信商户平台-》账户设置-》 API安全 中下载的
         */
        KeyStore keyStore = KeyStore.getInstance("PKCS12");
        //P12文件目录 证书路径，这里需要你自己修改，linux下还是windows下的根路径
        FileInputStream instream = new FileInputStream("/home/project/wx_cert/1289663601_apiclient_cert.p12");
        // FileInputStream instream = new FileInputStream("G:\\hurui-project/hai-parent/hai-service/src/main/java/privatekey/1289663601_apiclient_cert.p12");
        try {
            keyStore.load(instream, "1289663601".toCharArray());//这里写密码..默认是你的MCHID
        } finally {
            instream.close();
        }
        SSLContext sslcontext = SSLContexts.custom().loadKeyMaterial(keyStore, "1289663601".toCharArray()).build();//这里也是写密码的
        SSLConnectionSocketFactory sslsf = new SSLConnectionSocketFactory(sslcontext, SSLConnectionSocketFactory.getDefaultHostnameVerifier());
        // Allow TLSv1 protocol only
        return HttpClients.custom().setSSLSocketFactory(sslsf).build();
    }

    public String doRefundRequest(String mchId, String url, String data) throws Exception {

        //小程序退款需要调用双向证书的认证
        CloseableHttpClient httpClient = readCertificate(mchId);
        try {
            HttpPost httpost = new HttpPost("https://api.mch.weixin.qq.com/secapi/pay/profitsharing"); // 设置响应头信息
            httpost.addHeader("Connection", "keep-alive");
            httpost.addHeader("Accept", "*/*");
            httpost.addHeader("Content-Type", "text/xml");
            httpost.addHeader("Host", "api.mch.weixin.qq.com");
            httpost.addHeader("X-Requested-With", "XMLHttpRequest");
            httpost.addHeader("Cache-Control", "max-age=0");
            httpost.addHeader("User-Agent", "Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.0) ");
            httpost.setEntity(new StringEntity(data, "UTF-8"));
            CloseableHttpResponse response = httpClient.execute(httpost);
            try {
                HttpEntity entity = response.getEntity();
                String jsonStr = EntityUtils.toString(response.getEntity(), "UTF-8");
                EntityUtils.consume(entity);
                return jsonStr;
            } finally {
                response.close();
            }
        } catch (Exception e) {
            throw new RuntimeException(e);
        } finally {
            httpClient.close();
        }
    }

    @RequestMapping(value = "/websocket", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "websocket")
    public ResponseData websocket(@RequestParam(name = "orderNo", required = true) String orderNo
    ) {
        try {

            HighOrder order = highOrderService.getOrderByOrderNo(orderNo);
            if (order.getHighChildOrderList().get(0).getGoodsType().equals(3)) {
                Map<String, Object> pushMsg = new HashMap<>();
                pushMsg.put("userId", order.getHighChildOrderList().get(0).getGoodsId());

                Map<String, Object> msgContent = new HashMap<>();
                msgContent.put("order", highOrderService.getGasOrderDetail(order.getOrderNo()));
                msgContent.put("voice", baiduVoiceService.text2audio(order.getHighChildOrderList().get(0).getGoodsName() + "加油站，收款：" + order.getTotalPrice()));
                pushMsg.put("message", JSONObject.toJSONString(msgContent));
                HttpsUtils.doPost("http://127.0.0.1:9901/msg/test/websocket", pushMsg, new HashMap<>());
            }

            return ResponseMsgUtil.success("null");

        } catch (Exception e) {
            log.error("HighOrderController --> unionStagingPay() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/gasStationQueryDetail", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "gasStationQueryDetail")
    public ResponseData gasStationQueryDetail() {
        try {

            return ResponseMsgUtil.success(shellGroupService.gasStationQueryDetail("0001"));

        } catch (Exception e) {
            log.error("HighOrderController --> gasStationQueryDetail() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/gasPageQueryAllStation", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "gasPageQueryAllStation")
    public ResponseData gasPageQueryAllStation() {
        try {

            gasService.getJiaHaoYouAllStation();

            return ResponseMsgUtil.success(null);

        } catch (Exception e) {
            log.error("HighOrderController --> gasPageQueryAllStation() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value = "/gasSyncRefund", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "gasSyncRefund")
    public ResponseData gasSyncRefund() {
        try {

            shellGroupService.gasSyncRefund(new Date(1659511289000L), "1659511289357");

            return ResponseMsgUtil.success(null);

        } catch (Exception e) {
            log.error("HighOrderController --> gasSyncRefund() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getJzStationListPage", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "getJzStationListPage")
    public ResponseData getJzStationListPage() {
        try {

            gasService.getJinZhuAllStation();

            return ResponseMsgUtil.success(null);

        } catch (Exception e) {
            log.error("HighOrderController --> gasSyncRefund() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/insertV2", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "支付")
    public ResponseData insertV2() {
        try {

            String orderNo = "HF2022080818504922206";
            JSONObject object = QianZhuConfig.insertV2("PLM100024", orderNo, "15585850137");
            object.put("orderNo", orderNo);
            return ResponseMsgUtil.success(object);
        } catch (Exception e) {
            log.error("HighOrderController --> getBackendToken() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    /*   @RequestMapping(value = "/QueryV2", method = RequestMethod.GET)
       @ResponseBody
       @ApiOperation(value = "查询订单号")
       public ResponseData QueryV2(@RequestParam(name = "orderNo", required = true) String orderNo) {
           try {

               HighOrder order = highOrderService.getOrderByOrderNo(orderNo);

               JSONObject orderObject = QianZhuConfig.QueryV2(orderNo);

               if (orderObject != null && orderObject.getLong("Code") == 999) {
                   // 订单失败  // 订单状态 1:订单正在处理中 2;订单成功:	3 订单失败
                   if (orderObject.getJSONObject("Data").getInteger("OrderState") == 3) {
                       // 订单失败
                       if (order.getOrderStatus() == 2) {
                           highOrderService.thirdOrderToRefund(order.getId());
                       } else {
                           highOrderService.thirdCancelOrder(order.getId());
                       }
                   }
                   // 订单状态 1:订单正在处理中 2;订单成功:	3 订单失败
                   if (orderObject.getJSONObject("Data").getInteger("OrderState") == 2) {
                       for (HighChildOrder childOrder : order.getHighChildOrderList()) {
                           childOrder.setChildOrdeStatus(3);
                       }
                       order.setOrderStatus(3);
                       order.setFinishTime(new Date());
                       highOrderService.updateOrder(order);
                   }
               }

               return ResponseMsgUtil.success(QianZhuConfig.QueryV2(orderNo));

           } catch (Exception e) {
               log.error("HighOrderController --> unionStagingPay() error!", e);
               return ResponseMsgUtil.exception(e);
           }
       }
   */
    @RequestMapping(value = "/getKfcOrderByOrderNo", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询肯德基订单")
    public ResponseData getKfcOrderByOrderNo(@RequestParam(name = "orderNo", required = true) String orderNo) {
        try {
            return ResponseMsgUtil.success(QianZhuConfig.getKfcOrderByOrderNo(orderNo));

        } catch (Exception e) {
            log.error("HighOrderController -> addOrder() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/starbucksOrderByOrderNo", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询星巴克订单")
    public ResponseData starbucksOrderByOrderNo(@RequestParam(name = "orderNo", required = true) String orderNo) {
        try {
            return ResponseMsgUtil.success(QianZhuConfig.starbucksOrderByOrderNo(orderNo));

        } catch (Exception e) {
            log.error("HighOrderController -> addOrder() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/thirdOrderToRefund", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "第三方退款")
    public ResponseData thirdOrderToRefund(@RequestParam(name = "orderNo", required = true) String orderNo) {
        try {

            HighOrder order = highOrderService.getOrderByOrderNo(orderNo);
            highOrderService.thirdOrderToRefund(order.getId());
            return ResponseMsgUtil.success("");

        } catch (Exception e) {
            log.error("HighOrderController -> addOrder() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/rechargeOrderByCy", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "城宇话费充值   ")
    public ResponseData rechargeOrderByCy() {
        try {

            JSONObject object = new JSONObject();

            object.put("mobile" , "18090580471");
            object.put("productId" , 172);
            object.put("agentOrderId" , "RCG" + DateUtil.date2String(new Date(), "yyyyMMddHHmmss") + IDGenerator.nextId(5));


            return ResponseMsgUtil.success(RechargeConfig.rechargeOrderByCy(object));

        } catch (Exception e) {
            log.error("HighOrderController -> addOrder() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/queryRechargeByCy", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "城宇查询订单")
    public ResponseData queryRechargeByCy(@RequestParam(name = "orderNo", required = true) String orderNo) {
        try {

            JSONObject object = new JSONObject();
            object.put("orderNo" , orderNo);
            return ResponseMsgUtil.success(RechargeConfig.queryRechargeByCy(object));

        } catch (Exception e) {
            log.error("HighOrderController -> addOrder() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/postIp", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "请求ip地址")
    public ResponseData postIp(HttpServletRequest request) {
        try {

            request.getHeader("regionId");
            if (request.getHeader("regionId") != null && request.getHeader("regionId").length() != 0) {
                System.out.println("111");
            }
            return ResponseMsgUtil.success(HttpsUtils.doPost("https://hsgcs.dctpay.com/brest/openApi/test"));

        } catch (Exception e) {
            log.error("HighOrderController -> addOrder() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
